///


// Core library for code-sense
#if defined(ENERGIA) // LaunchPad MSP430, Stellaris and Tiva, Experimeter Board FR5739 specific
#include "Energia.h"
#else // error
#error Platform not defined
#endif


// Include application, user and local libraries
#include "SPI.h"

// Screen selection
#define K35_SPI // HX8353E K35_SPI

#if defined(K35_SPI)
#include "Screen_K35_SPI.h"
Screen_K35_SPI myScreen;

#elif defined(HX8353E)
#include "Screen_HX8353E.h"
Screen_HX8353E myScreen;

#else
#error Unknown screen
#endif


// Beware of RAM limitations
#if defined(__MSP430F5529__) || defined(__MSP432P401R__)
#define ROWS 32 // max 80
#define COLS 32 // max 60
#elif defined(__LM4F120H5QR__) || defined(__TM4C123GH6PM__)
#define ROWS 80 // max 80
#define COLS 60 // max 60
#elif defined(__TM4C1294NCPDT__) || defined(__TM4C1294XNCZAD__) || defined(__MSP432P401R__)
#define ROWS 128 // max 128
#define COLS 128 // max 128
#else
#error Board not supported
#endif

// Define variables and constants
uint8_t _screen[2][ROWS][COLS];
uint32_t chrono;
uint8_t page;
uint16_t colours[16];
uint16_t generation;
uint8_t rowSize, colSize;
uint8_t i, j;
uint16_t x, y, z;
int var;
#define LED RED_LED

// Following includes for Energia only
#include "SPI.h"


#include "Energia_logo_100_132.h"


void setup()
{
pinMode(LED, OUTPUT);

//    // No need for INPUT_PULLUP
//    pinMode(StopButton, INPUT_PULLUP);
//    pinMode(NewGameButton, INPUT_PULLUP);
    
    myScreen.begin();
    x = 0;
    y = 0;
    z = 0;
    var = 0;    // Initialisation variable eclairage LED
    rowSize = myScreen.screenSizeX() / ROWS;
    colSize = myScreen.screenSizeY() / COLS;
    
    delay(10);
    myScreen.setPenSolid(true);
    
    // 0-7 dying: cold colours
    // from green to blue to black
    colours[ 0] = myScreen.calculateColour(  0, 255,   0);
    colours[ 1] = myScreen.calculateColour(  0, 204,  51);
    colours[ 2] = myScreen.calculateColour(  0, 153, 102);
    colours[ 3] = myScreen.calculateColour(  0, 102, 153);
    colours[ 4] = myScreen.calculateColour(  0,  51, 204);
    colours[ 5] = myScreen.calculateColour(  0,   0, 255);
    colours[ 6] = myScreen.calculateColour(  0,   0, 127);
    colours[ 7] = myScreen.calculateColour(  0,   0,   0);
    
    
    // 8-15 living: hot colours
    // from red to orange to yellow
    colours[ 8] = myScreen.calculateColour(255,   0,   0);
    colours[ 9] = myScreen.calculateColour(255,  43,   0);
    colours[10] = myScreen.calculateColour(255,  85,   0);
    colours[11] = myScreen.calculateColour(255, 127,   0);
    colours[12] = myScreen.calculateColour(255, 171,   0);
    colours[13] = myScreen.calculateColour(255, 213,   0);
    colours[14] = myScreen.calculateColour(255, 255,   0);
    colours[15] = myScreen.calculateColour(255, 255, 255);
    
    myScreen.setFontSolid(false);
    myScreen.setFontSize(0);
    myScreen.gText((myScreen.screenSizeX()-14*myScreen.fontSizeX())/2, 40, "Eclairement LED");
    logo50();
}

void loop()
{


myScreen.dRectangle(0, 0, 300, 20 , colours[1]);
myScreen.triangle(250, 100, 275, 75, 300, 100, colours[8]);
myScreen.triangle(250, 120, 275, 145, 300, 120, colours[8]);

// Utilisation ecran tactile et Detection appui
if (myScreen.isTouch()>0)
{
  myScreen.getTouch(x,y,z);

  if (z>200)
  {
    if ((x<300&&x>250) && (y<100 && y>75) && (var <= 255))
    {
      var = var +10;
      analogWrite(LED,var);
      //delay(30);
    }
  }
  else if((x<300 && x>250) && (y>120 && y<245) && (var >= 0))
  {
   var = var -10;
   analogWrite(LED,var);
  //delay(30);
  }
}


    //    // touch to stop
//    if (digitalRead(StopButton) == 0)
//    {
//        myScreen.clear();
//        while (1);
//    }
    

}

void logo50()
{
    uint32_t p;
    uint16_t c;
    uint16_t x00 = 0;
    uint16_t y00 = 0;
    uint16_t i00 = 0;
    uint16_t j00 = 0;
    
    if ((myScreen.screenSizeX() > x_Energia_logo_100_132_bmp)) {
        x00 = (myScreen.screenSizeX() - x_Energia_logo_100_132_bmp) / 2;
    } else {
        i00 = (x_Energia_logo_100_132_bmp - myScreen.screenSizeX()) / 2;
    }
    if ((myScreen.screenSizeY() > y_Energia_logo_100_132_bmp)) {
        y00 = (myScreen.screenSizeY() - y_Energia_logo_100_132_bmp) / 2;
    } else {
        j00 = (y_Energia_logo_100_132_bmp - myScreen.screenSizeY()) / 2;
    }
    p = (uint32_t)x_Energia_logo_100_132_bmp * y_Energia_logo_100_132_bmp;
    
    for (uint16_t i=0; i<x_Energia_logo_100_132_bmp; i++) {
        for (uint16_t j=0; j<y_Energia_logo_100_132_bmp; j++) {
            if ((x00+i < myScreen.screenSizeX()) && (y00+j < myScreen.screenSizeY())) {
                c = pic_Energia_logo_100_132_bmp[i*y_Energia_logo_100_132_bmp + j];
                myScreen.point(x00+i-i00, y00+j-j00, c);
            }
        }
    }
}












